@@ -1,5 +1,5 @@
 from sqlglot import exp
-from sqlglot.dialects.dialect import rename_func, no_ilike_sql
+from sqlglot.dialects.dialect import no_ilike_sql, rename_func
 from sqlglot.dialects.hive import Hive, HiveMap
 from sqlglot.helper import list_get
 
@@ -101,3 +101,6 @@ class Spark(Hive):
             exp.StructKwarg: lambda self, e: f"{self.sql(e, 'this')}: {self.sql(e, 'expression')}",
             HiveMap: _map_sql,
         }
+
+        def bitstring_sql(self, expression):
+            return f"X'{self.sql(expression, 'this')}'"
