@@ -885,10 +885,6 @@ class Reference(Expression):
     arg_types = {"this": True, "expressions": True}
 
 
-class Table(Expression):
-    arg_types = {"this": True, "db": False, "catalog": False}
-
-
 class Tuple(Expression):
     arg_types = {"expressions": False}
 
@@ -998,6 +994,10 @@ QUERY_MODIFIERS = {
 }
 
 
+class Table(Expression):
+    arg_types = {"this": True, "db": False, "catalog": False, "joins": False}
+
+
 class Union(Subqueryable, Expression):
     arg_types = {
         "with": False,
@@ -1811,6 +1811,10 @@ class Like(Binary, Predicate):
     pass
 
 
+class Distance(Binary):
+    pass
+
+
 class LT(Binary, Predicate):
     pass
 
@@ -1912,6 +1916,10 @@ class IgnoreNulls(Expression):
     pass
 
 
+class RespectNulls(Expression):
+    pass
+
+
 # Functions
 class Func(Condition):
     """
@@ -2191,6 +2199,10 @@ class Greatest(Func):
     is_var_len_args = True
 
 
+class GroupConcat(Func):
+    arg_types = {"this": True, "separator": False}
+
+
 class If(Func):
     arg_types = {"this": True, "true": True, "false": False}
 
